Package 'tekton'

Title: 'pkgdown' Template for 'tesselle' Packages
Description: This is a private template for use by 'tesselle' packages. Please don't use it for your own code.
Authors: Nicolas Frerebeau [aut, cre] (ORCID: <https://orcid.org/0000-0001-5759-4944>), Université Bordeaux Montaigne [fnd] (ROR: <https://ror.org/03pbgwk21>), CNRS [fnd] (ROR: <https://ror.org/02feahw73>)
Maintainer: Nicolas Frerebeau <[email protected]>
License: GPL (>= 3)
Version: 0.0.0.9000
Built: 2026-05-12 11:23:49 UTC
Source: https://codeberg.org/tesselle/tekton

Help Index


Code Coverage of a Package

Description

Code Coverage of a Package

Usage

coverage(pkg = ".", dest_dir = tempdir(), ...)

Arguments

pkg

A character string specifying the path to the package.

dest_dir

A character string specifying the path to the output directory.

...

Further parameters to be passed to covr::package_coverage().

Examples

## Not run: 
coverage()

## End(Not run)